%Belyk, March 2019
%preprocessing supplement for GM tissue masking
%assumes all other preprocessing steps already done
%tissue masks from segment are in native space, this script assumes that
%these masks have already been normalized


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%STUFF THAT NEEDS SETTING%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%list of subject folder names
subjects = {'p3', 'p4', 'p5','p6', 'p7','p8','p9' 'p10','p11', 'p12', 'p13', 'p14', 'p15'};

%list of run names, should also be name of run folders
runs = {'imit', 'mot'};
no_runs = length(runs); %count 'em

%which preprocessing steps have been done? (affects filenames to retrieve_
prefixes='smw';

%runs to skip, missing data
%format is 'subjectrun' entries from subjects and runs arrays with no space
skip_runs=['none'];

%where the data is
basepath = '/Users/m.belyk/Documents/MATLAB/PLSdat/';

%%%Image preprocessing %%%

tic %a time thingy
for s = subjects %loop through subjects
    %steps to do once per subject go here
    
    disp('%%%%%%%%%%%%%%%%%%%%%%%%') 
    disp(strcat("Start Subject: ", s))
    disp('%%%%%%%%%%%%%%%%%%%%%%%%') 
    
    %build path to ANAT folder
    anatpath = fullfile(basepath, s,'anat');
    
    
    
        %processing BOLD images
    for r = runs %loop through runs in subjects
        %skip missing runs
        if ismember(strcat(s,r), skip_runs)%should this run be skipped
            disp(strcat("%%% Skipping:", s," ",r,"","%%%"))
        else

            %build path to BOLD folders
            boldpath = fullfile(basepath, s,r); %in this version of the script I add _tp later because I'm an idiot who doesn't give consistent names


            %fetch tissue segmentations for normalized T1
            %ci = GM output from segment, w__ indicates normalized
            GM_header  = spm_vol(fullfile(anatpath,'c1wanat.nii'));

            %convert to binary masks
            GM_msk   = spm_read_vols(GM_header{1})>0;

            %get resting state image, needed downstream
            tsk_header = spm_vol(strcat(boldpath,'/',prefixes,r,'_tp','.nii'));
            tsk_image = spm_read_vols(tsk_header{1});
            tsk_size = size(tsk_image);
            n_volumes= tsk_size(4); %automate volume fetching

            %Mask
            tsk_GM   =  bsxfun(@times, tsk_image, GM_msk); %full GM for testing

            %save
            tsk_GM_header = tsk_header;
            for v = 1:n_volumes
               tsk_GM_header{1}(v).fname = strcat(boldpath, '/k', prefixes,r,'.nii'); %append k to filename + previous prefixes
               tsk_GM_header{1}(v).fname = tsk_GM_header{1}(v).fname{1}; %unpack cell array
               spm_write_vol(tsk_GM_header{1}(v), tsk_GM(:,:,:,v));      %write volumes one at a time
            end
        end %end runskip if
    end %end run loop
    
end %end subject loop
