%Belyk, September 2047
%The basic idea of this script is to load predefined processing jobs built
%in the GUI with one sample scan in mind, and it automate replacing some of
%its settings (mostly filepaths) and logfiles 
%data should be outputs processed be preproc.m
%the design implemented here is the block design implemented in https://royalsocietypublishing.org/doi/full/10.1098/rsos.172208
%you will need to make changes so that
%ffx{1}.spm.stats.fmri_spec.sess.cond(c) receives inputs that reflect your
%study design

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%STUFF THAT NEEDS SETTING%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%list of subject folder names
subjects = {'c1', 'c2', 'c3b', 'c4', 'c5', 'c6','c10', 'c11', 'c12', 'c13', 'c14', 'c15'};

%list of run names, should also be name of run folders
runs = {'bold1', 'bold2','bold3', 'bold4'};
no_runs = length(runs); %count 'em

%list of coniditions
conds = {"low", "comfort", "mid", "high"};
no_conds = length(conds); %count 'em

%runs to skip, missing data
skip_runs=["c10bold1"];

%number of volumes per functional run
n_volumes = 256;

%number of volumes per block
block_dur = 8;

%the number of blocks per condition
no_blocks = 4;

%in seconds
TR = 2.5;

%where the data is
basepath = '/Users/Belykm/Documents/MATLAB/Phonotopy_processing/';

%for testing only
s = subjects{1};
r = runs{2};
c = conds{1};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%Fixed Effects Analysis%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load("ffx.mat")

tic %a time thingy
for s = subjects %loop through subjects
    %steps to do once per subject go here
    
    disp('%%%%%%%%%%%%%%%%%%%%%%%%') 
    disp(strcat("Start Subject: ", s))
    disp('%%%%%%%%%%%%%%%%%%%%%%%%') 
    
    for r = runs %loop through runs in subjects
        %skip missing runs
        if ismember(strcat(s,r), skip_runs)%should this run be skipped
            disp(strcat("%%% Skipping:", s," ",r,"","%%%"))
        else      
            
            %build path to BOLD folders
            boldpath = fullfile(basepath, s,r);

            %where condition onsets are stored
            designpath = strcat(boldpath,"/design/");

            %load in conditions onset times
            ffx_onsets = zeros(no_blocks,no_conds); %empty matrix for filling
            col = 0; %row looping through rows of empty matrix
            for c = conds
                col = col +1; %iterate
                new_onsets = csvread(strcat(designpath,r,"_",c{1},".csv"));%read in onset times for each condition
                ffx_onsets(:,col) = new_onsets; %store conditions in matrix. rows = blocks, cols = conditions
            end
        
            %setup ffx job
            ffx{1}.spm.stats.fmri_spec.dir = boldpath;%where the stuff
            ffx{1}.spm.stats.fmri_spec.timing.RT = TR;%time per volume
        
            for v = 1:n_volumes %loop through volumes to point to the data, w signifies coregistered and normalized
                ffx{1}.spm.stats.fmri_spec.sess.scans{1} = strcat(boldpath,'/w',r,'.nii,',num2str(v));
            end
        
        
            %fill in design details
            for c = 1:size(conds,2)%loop through conditions, numerically this time
                ffx{1}.spm.stats.fmri_spec.sess.cond(c).name = conds{c}; %block onset times
                ffx{1}.spm.stats.fmri_spec.sess.cond(c).onset = ffx_onsets(:,c); %block onset times
                ffx{1}.spm.stats.fmri_spec.sess.cond(c).duration = block_dur; %block duration
            end
        end%finish else
        
        
        
       %execute normalization job
        spm_jobman('run',ffx)
        disp(strcat("Done ffx: ", s,'/', r)) 
        
        end %finish else
        
    end %finish run loop
    toc %time for subject
end %finish subject loop

            disp('%%%') 
            disp('Fin') %message to console
            disp('%%%')       